# Fatty Acylizer

This is the mathematical model employed by the [Fatty Acylizer web server](https://fatty-acylizer.lipid.at).

## Installation

```bash
pip install fatty-acylizer
```

Or alternatively from GitHUB:
```bash
pip install git+https://github.com/biochemical-genetics/fatty-acylizer.git
# or
git clone https://github.com/biochemical-genetics/fatty-acylizer.git
cd fatty-acylizer
pip install .
```

## License Info

When using the code in a publication, please cite:
